==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridClipboardEventEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDetailDescriptionMetadata } from "./WebGridClipboardEventDetailDescriptionMetadata";
import { WebGridClipboardEventEventArgsDescription } from "./WebGridClipboardEventEventArgsDescription";
/**
 * @hidden
 */
var WebGridClipboardEventEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridClipboardEventEventArgsDescriptionMetadata, _super);
    function WebGridClipboardEventEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridClipboardEventEventArgsDescriptionMetadata.b = function (a) {
        if (WebGridClipboardEventEventArgsDescriptionMetadata.a == null) {
            WebGridClipboardEventEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridClipboardEventEventArgsDescriptionMetadata.c(WebGridClipboardEventEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebGridClipboardEventEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridClipboardEventEventArgsDescriptionMetadata.a);
        WebGridClipboardEventDetailDescriptionMetadata.d(a);
    };
    WebGridClipboardEventEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridClipboardEventEventArgs");
        a.item("Detail", "ExportedType:WebGridClipboardEventDetail");
    };
    WebGridClipboardEventEventArgsDescriptionMetadata.d = function (a) {
        WebGridClipboardEventEventArgsDescriptionMetadata.b(a);
        a.aa("WebGridClipboardEventEventArgs", function () { return new WebGridClipboardEventEventArgsDescription(); });
        a.z("WebGridClipboardEventEventArgs", WebGridClipboardEventEventArgsDescriptionMetadata.a);
    };
    WebGridClipboardEventEventArgsDescriptionMetadata.$t = markType(WebGridClipboardEventEventArgsDescriptionMetadata, 'WebGridClipboardEventEventArgsDescriptionMetadata');
    WebGridClipboardEventEventArgsDescriptionMetadata.a = null;
    return WebGridClipboardEventEventArgsDescriptionMetadata;
}(Base));
export { WebGridClipboardEventEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridClipboardEventEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDetailDescriptionMetadata } from "./WebGridClipboardEventDetailDescriptionMetadata";
import { WebGridClipboardEventEventArgsDescription } from "./WebGridClipboardEventEventArgsDescription";
/**
 * @hidden
 */
var WebGridClipboardEventEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridClipboardEventEventArgsDescriptionMetadata, _super);
    function WebGridClipboardEventEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridClipboardEventEventArgsDescriptionMetadata.b = function (a) {
        if (WebGridClipboardEventEventArgsDescriptionMetadata.a == null) {
            WebGridClipboardEventEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridClipboardEventEventArgsDescriptionMetadata.c(WebGridClipboardEventEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebGridClipboardEventEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridClipboardEventEventArgsDescriptionMetadata.a);
        WebGridClipboardEventDetailDescriptionMetadata.d(a);
    };
    WebGridClipboardEventEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridClipboardEventEventArgs");
        a.item("Detail", "ExportedType:WebGridClipboardEventDetail");
    };
    WebGridClipboardEventEventArgsDescriptionMetadata.d = function (a) {
        WebGridClipboardEventEventArgsDescriptionMetadata.b(a);
        a.ac("WebGridClipboardEventEventArgs", function () { return new WebGridClipboardEventEventArgsDescription(); });
        a.ab("WebGridClipboardEventEventArgs", WebGridClipboardEventEventArgsDescriptionMetadata.a);
    };
    WebGridClipboardEventEventArgsDescriptionMetadata.$t = markType(WebGridClipboardEventEventArgsDescriptionMetadata, 'WebGridClipboardEventEventArgsDescriptionMetadata');
    WebGridClipboardEventEventArgsDescriptionMetadata.a = null;
    return WebGridClipboardEventEventArgsDescriptionMetadata;
}(Base));
export { WebGridClipboardEventEventArgsDescriptionMetadata };
